"""
_MotT0Page_
Generic class representing the index page of the MotT0 monitoring system.
 
""" 
from WMCore.WebTools.Page import TemplatedPage
 

from Table import *
from TableContents import *

from Statistics import *
from Heartbeats import * 
from RunDetails import *
import threading, os,time

class MotT0Index(TemplatedPage):

    cacheFile="var/Mott0CachedIndex.html"
    flagFile="var/Mott0Refrashing"
    tmpFile="var/Mott0-tmp"
    # If a refrashing is taking too much I cut it
    refrashingTimeout= 60*15
    
    
    def __init__(self, kwords,DASUrl,templatedir):
      self.DASUrl=DASUrl
      self.params=kwords
      self.templatedir = templatedir
      
      
      
    def getTemplate(self):
       self.checkOldRefrashingFlag()
       eParams={
            "title": "Error",
            "time" : ctime(),
            "tmplPath": self.templatedir,
            "msg": "No cached page found, a new one is being created right now. Refrash the page in few minutes, please "
              } 
       if self.existsCachedPage():
         cacheTime=str(self.getLastTimeCached())
         content=self.getCachedPage()
         message="<B>Caution the page has been cached at: %s</B><br/>A new page is being created right now. <BR>" %(cacheTime)
         content.replace("<body>","<body>"+ message)
         cParams={ 
            "content":content
            }
       #if the  page is a special one I don't want to use the caching system
       try:
            tab=str(self.params['table'])
            t=generateIndexThread(self.params, self.DASUrl, self.templatedir,self,saveData=False)
            t.start()
            #wait for the final response
            t.join()
            return t.page
       except:
        if self.alreadyRefrashingFlag(): 
           if self.existsCachedPage():
               return self.templatepage('cached', **cParams )
           else:
               return self.templatepage('error', **eParams )
        else:
         self.setRefrashingFlag() # this flag will be disabled by the thread that accomplishes the result
         if self.existsCachedPage():
           t=generateIndexThread(self.params, self.DASUrl, self.templatedir,self)
           t.start()
           return self.templatepage('cached', **cParams ) 
         else: 
           t=generateIndexThread(self.params, self.DASUrl, self.templatedir,self)
           t.start()
           return self.templatepage('error', **eParams )
    
############################################################ File operations: inter process comunication
    def checkOldRefrashingFlag(self):
        #this  service routine is used to avoid locks when the service is interrupted before delating the refrashing flag
        if self.alreadyRefrashingFlag(): 
            print "Mott0Index: checking refrashing flag" 
            statinfo = os.stat(self.flagFile)
            cacheTime=  statinfo.st_mtime
            with open(self.tmpFile, 'w') as f:
                  f.write("1")
            statinfo = os.stat(self.tmpFile)
            print "refrashing flag:"+time.ctime(cacheTime)
            print "now            :"+time.ctime(statinfo.st_mtime)
            if statinfo.st_mtime-cacheTime>self.refrashingTimeout:
                self.removeRefrashingFlag()
                print "Mott0Index: force delate refrashing flag. time=%s"%(str(statinfo.st_mtime-cacheTime))
            os.remove(self.tmpFile)

    def getCachedPage(self):
       with open(self.cacheFile, 'r') as f:
         read_data = f.read()
       f.closed
       return read_data 
    
    def existsCachedPage(self):
        try:
          f=open(self.cacheFile, 'r')
          f.close()
          return True
        except:
          return False
    
    def saveCachedPage(self, page):
       with open(self.cacheFile, 'w') as f:
        f.write(page)    
        
        
    def setRefrashingFlag(self):
       with open(self.flagFile, 'w') as f:
        f.write("1")
        
    def removeRefrashingFlag(self):
        print "Removing Refrashing flag "
        try:
         os.remove(self.flagFile)
         print "refrashing flag="+str(self.alreadyRefrashingFlag())
        except:
          print "File not found"
        
    def alreadyRefrashingFlag(self):
        try:
          f=open(self.flagFile, 'r')
          f.close()
          return True
        except:
          return False
    
    def getLastTimeCached(self):
        try:
         statinfo = os.stat(self.cacheFile)
         #print "TIME=="+time.ctime(statinfo.st_mtime)
         return time.ctime(statinfo.st_mtime)
        except: return 0
         

#################################################################3
class generateIndexThread(threading.Thread):
    page=""
    heartbeatsCode=""
    runsDetailsCode=""
    statsCode=""
    exprJTablesCode=""
    repkJTablesCode=""
    recoJTablesCode=""
    alcaJTablesCode=""
    detailRunRowNumber=10    
    title="MotT0 main page"
    
    
    def __init__ ( self, params, DASUrl, templatedir,templatePage,saveData=True):
      self.saveData=saveData
      self.templatePage=templatePage
      self.DASUrl=DASUrl
      self.params=params
      self.templatedir = templatedir
      threading.Thread.__init__ ( self )
    
    def run(self):
      #see TableContents for table content information
      contents=[exprJ(self.params),exprMJ(self.params),repkJ(self.params),repkMJ(self.params),recoJ(self.params),recoMJ(self.params),alcaJ(self.params),alcaMJ(self.params)]
      #generate code for tables
      try:
        h = Heartbeats(self.DASUrl) 
        self.heartbeatsCode = h.buildHeartbeatsCode()
        r = RunDetails(self.DASUrl,self.detailRunRowNumber,self.params)
        self.runsDetailsCode = r.buildRunDetailsCode()
        s= Statistics(self.DASUrl)
        self.statsCode= s.buildStatsCode()
        #print " Jobs tables"
        for c in range(0,len(contents),2):
            #print "creating "+ str(contents[c].name)+"  "+ str(contents[c+1].name)
            dt=DoubleTables(self.DASUrl,self.params,contents[c:c+2])
            setattr(self, str(contents[c].name)+'TablesCode',dt.buildTablesCode())        
      except ConnectionException, e:
        try:
          setattr(self,''+e.name+'Code',"<B> Connection Error </B>")
        except:
          pass
      params={
            "title": self.title,
            "time" : ctime(),
            "tmplPath": self.templatedir,
            "heartbeats": self.heartbeatsCode,
            "runsT":self.runsDetailsCode,
            'stats':self.statsCode,
            'exprJTables':self.exprJTablesCode,
            'repkJTables':self.repkJTablesCode,
            'recoJTables':self.recoJTablesCode,
            'alcaJTables':self.alcaJTablesCode
              }
      self.templatePage.removeRefrashingFlag()
      if len(self.alcaJTablesCode)+len(self.recoJTablesCode)>10:
        #BUGFIX: if the connection is interrupted the result is not cached
        self.page=self.templatePage.templatepage('system', **params )
        if self.saveData==True:
          self.templatePage.saveCachedPage(self.page)
      
 
        
##############################################################################

class DoubleTables(object):
  """ This class is used to generate the pair of tables [express/repack/reco/alca] acquired Jobs / Merge acquired Jobs   
  """
  
  def __init__(self,DASUrl,params,tables,pageUrl=""):
      self.DASUrl = DASUrl
      self.params=params
      self.tables=tables
      self.pageUrl=pageUrl
     
    
  def buildTablesCode(self):
    res="<table border=\"0\" cellspacing=\"2\"> <tr>"
    for tab in self.tables:
      res+="<td class=\""+tab.CSSclass+"\">"
      if '?' in tab.URL:
           tab.URL=tab.URL%(self.params['run_id'])+'&'
      else:tab.URL+='?'
      table= Table(self.DASUrl,tab.URL+"uplimit="+str(tab.upLimit) +'&downlimit='+str(tab.downLimit))
      if self.pageUrl=="": res+=table.longTableCode(tab,'system?')
      else:res+=table.longTableCode(tab,self.pageUrl)
      res+="</td>"
    res+="</tr></table>"
    return res
    

#################################################################################################



