"""
_MotT0Page_
Generic class representing a page of the MotT0 monitoring system.
 
""" 
from WMCore.WebTools.Page import TemplatedPage

from Table import *
from TableContents import *

from Statistics import *
from MotT0Index import DoubleTables


class MotT0Run(TemplatedPage):
    errorString="<B> Connection Error </B>"
    expressConfCode=""
    confCode=""
    statsCode=""
    exprFTablesCode=""
    repkFTablesCode=""
    recoFTablesCode=""
    alcaFTablesCode=""
    streamerTableCode=""
    detailRunRowNumber=1
    title="MotT0 Run %s page"
    
    
    
    def __init__(self, kwords,DASUrl,templatedir):
      self.params=kwords
      self.templatedir = templatedir
      self.runid=self.params['run_id']
      self.title=self.title%(self.runid)
      self.DASUrl=DASUrl
      #see TableContents for table content information
      contents=[exprTF(self.params),exprF(self.params),repkTF(self.params),repkF(self.params),recoTF(self.params),recoF(self.params),alcaTF(self.params),alcaF(self.params)]
      #generate code for tables
      try:
        ec=ExpressConfig()
        ect=Table(DASUrl,ec.url%(self.runid))
        self.expressConfCode= ect.genericTableCode(ec.colDecorators,"Express Configuration")
        
        gc=GeneralConfig()
        gct=Table(DASUrl,gc.url%(self.runid))
        self.confCode= gct.genericTableCode(gc.colDecorators,"Global Configuration")
        
        s= Statistics(DASUrl,self.runid)
        self.statsCode= s.buildStatsCode()
        
        streamC=streamers(self.params)
        streamerTable=Table(DASUrl,streamC.URL%(str(self.runid))+"&uplimit="+str(streamC.upLimit) +'&downlimit='+str(streamC.downLimit))
        self.streamerTableCode= streamerTable.longTableCode(streamC,"run?run_id="+str(self.runid))
        
        for c in range(0,len(contents),2):
            #print "creating "+ str(contents[c].name)+"  "+ str(contents[c+1].name)
            dt=DoubleTables(DASUrl,self.params,contents[c:c+2],pageUrl="run?run_id="+str(self.runid))
            setattr(self, str(contents[c+1].name)+'TablesCode',dt.buildTablesCode())        
      except ConnectionException, e:
          pass
      
    
    def getTemplate(self):
       params={
            "title": self.title,
            "runid": self.runid,
            "time" : ctime(),
            "tmplPath": self.templatedir,
            'stats': max(self.statsCode,self.errorString),
            'exprFTables':max(self.exprFTablesCode,self.errorString),
            'repkFTables':max(self.repkFTablesCode,self.errorString),
            'recoFTables':max(self.recoFTablesCode,self.errorString),
            'alcaFTables':max(self.alcaFTablesCode,self.errorString),
            'runConfigExpressKeyT':max(self.expressConfCode,self.errorString),
            'runConfigKeyT':max(self.confCode,self.errorString),
            'streamerTable':max(self.streamerTableCode,self.errorString)
              }
       return self.templatepage('run', **params )


####################### special columns for configuration tables:
   
class rpProcVersion(genericColumn):
   colName="REPACK:Proc Version"
   attrNames=["rp_proc_version"]
   
class roProcVersion(genericColumn):
   colName="RECO:Proc Version"
   attrNames=["rp_proc_version"]
class alProcVersion(genericColumn):
   colName="ALCA:Proc Version"
   attrNames=["al_proc_version"]

class roReco(genericColumn):
   colName="Reco"
   attrNames=["ro_reco"]
   
class alAlcaskim(genericColumn):
   colName="Alcaskim"
   attrNames=["al_alcaskim"]
   
   
class roCmsswVersion(genericColumn):
   colName="RECO: Cmssw Version"
   attrNames=["ro_cmssw_version"]
   
class alCmsswVersion(genericColumn):
   colName="ALCA: Cmssw Version"
   attrNames=["al_cmssw_version"]   
   
class roGlobalTag(genericColumn):
   colName="RECO:Global Tag"
   attrNames=["ro_global_tag"]
   
class roConfUrl(confUrl):
   colName="RECO:Config  Url"
   attrNames=["ro_config_url"]
         
class alConfUrl(confUrl):
   colName="ALCA:Config  Url"
   attrNames=["al_config_url"]  
   
class AMConfUrl(confUrl):
   colName="Alca Merge Config  Url"
   attrNames=["alcamerge_config_url"]
###########################################################configuration
class configuration(object):
   url=""

class ExpressConfig(configuration):
  url="express_config?run=%s&stream="
  colDecorators=[stream(),splitInProgress(),procVersion(),confUrl(),globalTag(),AMConfUrl()]

class GeneralConfig(configuration):
  url="general_config?run=%s"
  colDecorators=[dataset(),rpProcVersion(),roReco(),roCmsswVersion(),roGlobalTag(),roConfUrl(),roProcVersion(),alAlcaskim(),alCmsswVersion(),alConfUrl(),alProcVersion()]

